@@ -251,7 +251,7 @@
     }
     
     
-    function sortTable() {
+function sortTable() {
   var table, rows, switching, i, x, y, shouldSwitch;
   table = document.getElementById("myTable");
   switching = true;
@@ -329,7 +329,7 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
                     <a href="javascript:void(0)" onclick="openPage('mabl')">Batches</a>
                     <a href="javascript:void(0)" onclick="openPage('maayl')">Academic Years</a>
                     <a href="javascript:void(0)" onclick="openPage('macll')">Classes</a>
-                    <a href="javascript:void(0)" onclick="openPage('macnl')">Courses</a>
+                    <a href="javascript:void(0)" onclick="openPage('macoul')">Course Names</a>
                     <a href="javascript:void(0)" onclick="openPage('mactl')">Course Types</a>
                     <a href="javascript:void(0)" onclick="openPage('madl')">Departments</a>
                     <a href="javascript:void(0)" onclick="openPage('madvl')">Divisions</a>
@@ -343,9 +343,10 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
                     <div class="row">
                         <div class="col-sm-6">
                             <a href="javascript:void(0)" onclick="openPage('mcbgl')">Blood Groups</a>
+                            <a href="javascript:void(0)" onclick="openPage('mcgl')">Gender</a>
                             <a href="javascript:void(0)" onclick="openPage('mcrnl')">Religion Names</a>
                             <a href="javascript:void(0)" onclick="openPage('mccnl')">Caste Names</a>
-                            <a href="javascript:void(0)" onclick="openPage('mccl')">Communities</a>
+                            <a href="javascript:void(0)" onclick="openPage('mccl')">Community Names</a>
                             <a href="javascript:void(0)" onclick="openPage('mcdtl')">Document Types</a>
                             <a href="javascript:void(0)" onclick="openPage('mcitl')">Institution Types</a>
                             <a href="javascript:void(0)" onclick="openPage('mcmsl')">Marital Status</a>
@@ -362,7 +363,7 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
                             <a href="javascript:void(0)" onclick="openPage('mcaql')">Admission Quotas</a>
                             <a href="javascript:void(0)" onclick="openPage('mcatl')">Applicant's Types</a>
                             <a href="javascript:void(0)" onclick="openPage('mcotl')">Occupations</a>
-                            <a href="javascript:void(0)" onclick="openPage('mccanl')">Currency Names</a>
+                            <a href="javascript:void(0)" onclick="openPage('mccorl')">Currency Names</a>
                         </div>
                     </div>
                 </div>
@@ -370,13 +371,13 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
                     <div class="menu-heading" style="padding-bottom:10px">App Common</div>
                     <a href="javascript:void(0)" onclick="openPage('macql')">Qualifications</a>
                     <a href="javascript:void(0)" onclick="openPage('masnl')">School Names</a>
-                    <a href="javascript:void(0)" onclick="openPage('macnl')">College Names</a>
+                    <a href="javascript:void(0)" onclick="openPage('macoll')">College Names</a>
                     <a href="javascript:void(0)" onclick="openPage('mainl')">Institution Names</a>
                     <a href="javascript:void(0)" onclick="openPage('macbel')">Board of Educations</a>
                     <a href="javascript:void(0)" onclick="openPage('macstl')">Staff Types</a>
                     <a href="javascript:void(0)" onclick="openPage('macscl')">Student Categories</a>
                     <a href="javascript:void(0)" onclick="openPage('macssl')">Student Status</a>
-                    <a href="javascript:void(0)" onclick="openPage('macsl')">Schemes</a>
+                    <a href="javascript:void(0)" onclick="openPage('macsl')">Scheme Names</a>
                     <a href="javascript:void(0)" onclick="openPage('macunl')">University Names</a>
                     <a href="javascript:void(0)" onclick="openPage('machgnl')">HSc Group Names</a>
                     <a href="javascript:void(0)" onclick="openPage('macdel')">Designations</a>
@@ -393,8 +394,38 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
             <div class="row" style="margin:0px">
                 <div class="col-sm-2">
                     <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Student Management</div>
-                    <a href="javascript:void(0)" onclick="openPage('studmsn')">New Student</a>
-                    <a href="javascript:void(0)" onclick="openPage('studmsl')">List Students</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsl')">List</a>
+                    <a href="javascript:void(0)" onclick="openPage('smspi')">General Info</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsci')">Contact Info</a>
+                    <a href="javascript:void(0)" onclick="openPage('smspe')">Previous Education</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsd')">Documants</a>
+                    <a href="javascript:void(0)" onclick="openPage('smssd1')">Other Details 1</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsod2')">Other Details 2</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsld')">Library Details</a>
+                    <a href="javascript:void(0)" onclick="openPage('smstd')">Transport Details</a>
+                    <a href="javascript:void(0)" onclick="openPage('smshd')">Hostel Details</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsfd')">Fees Details</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsa')">Activities</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsss')">Sent SMS</a>
+                    <a href="javascript:void(0)" onclick="openPage('smssw')">Sent WhatsApp</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsse')">Sent Email</a>
+                    <a href="javascript:void(0)" onclick="openPage('smssm')">Sent Messages</a>
+                    <a href="javascript:void(0)" onclick="openPage('smsa')">Acess / Permission</a>
+                </div>
+            </div>
+        </div>  
+    </div>
+    
+    <div class="dropdown2">
+        <button class="dropbtn">Administrator
+            <i class="fa fa-caret-down"></i>
+        </button>
+        <div class="dropdown-content" style="padding-bottom:10px">
+            <div class="row" style="margin:0px">
+                <div class="col-sm-2">
+                    <div class="menu-heading" style="padding-bottom:10px;padding-top:10px">Admin Management</div>
+                    <a href="javascript:void(0)" onclick="openPage('ampl')">Principal</a>
+                    <a href="javascript:void(0)" onclick="openPage('amvpl')">Vice Principal</a>
                 </div>
             </div>
         </div>  
@@ -450,14 +481,7 @@ var URL="https://ims.j2jsoftwaresolutions.in/";
 
      </div>  
     
-    <div class="footerbar2">
-    &nbsp;</div>
-     <!--<script src="2https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous"></script>-->
-    
-<!--
-<script src="https://code.jquery.com/ui/1.12.0/jquery-ui.min.js" integrity="sha256-eGE6blurk5sHj+rmkfsGYeKyZx3M4bG+ZlFyA7Kns7E=" crossorigin="anonymous"></script>
-<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.6/umd/popper.min.js"></script>
--->
+    <div class="footerbar2">&nbsp;</div>
 <script>                 
 function openDeleteConfirmation(id,action,method,text,callback) {
     $('#delID').val(id);
@@ -505,34 +529,41 @@ function callDelete() {
     $.post(URL+"webservice.php?action="+$('#delAction').val()+"&method="+$('#delMethod').val(),param,function(data){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
-             //$('#confirmationtoadd').modal("hide"); 
-             $('#success_modal').modal("show");
-             //$('#delCallback').val()();    
+             $('#delete_confirmation').modal("hide");  
+             $('#delete_success_modal').modal("show");
+             $('#delete_success_modal_title').html(obj.message);
+             list();    
         }   else {
-            $('#ErrCommon').html(print_inlineError(obj.message));
+           $('#delete_failure_modal_title').html(obj.message);
         }
-        });
+    });
 }
 </script>
-<script>
-//Character Limitations
-
- /*$('#Code').keypress(function(e) {
-      var letters=/^[0-9]/g; //g means global
-      if(!(e.key).match(letters)) e.preventDefault();
-    });
-    
-   $('#onlyalpha').keypress(function(e) {
-      var letters=/^[a-z]/gi; //i means ignorecase
-      if(!(e.key).match(letters)) e.preventDefault();
-    });
-    
-    $('#speclchar').keypress(function(e) {
-      var letters=/^[0-9a-z]/gi; 
-      if((e.key).match(letters)) e.preventDefault();
-    }); */
-    
-   
-
-</script>
+<div class="modal fade" id="delete_success_modal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
+    <div class="modal-dialog modal-dialog-centered">
+        <div class="modal-content" style="width: 300px;margin: 0px auto;background: #fff !important;">
+            <div class="modal-body" style="text-align: center;">
+                <div id="sucess">
+                    <img style="width:96px;" src="assets/deleted_successfully.png" alt=""/>
+                </div>
+                <h3 id="delete_success_modal_title" style="font-size: 18px;"></h3>  
+                 <button type="button" href="javascript:void(0)" onclick="$('#delete_success_modal').modal('hide')" class="btn-save">Continue</button>         
+            </div>
+        </div>
+    </div>
+</div>
+<div class="modal fade" id="delete_failure_modal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
+    <div class="modal-dialog modal-dialog-centered">
+        <div class="modal-content">
+            <div class="modal-body" style="text-align: center;">
+                <div id="sucess">
+                    <img style="width: 150px;" src="sucess.gif" alt=""/>
+                </div>
+                <h3 id="delete_failure_modal_title"></h3>  
+                 <button type="button" href="javascript:void(0)" onclick="$('#delete_success_modal').modal('hide')" class="btn-save">Continue</button>         
+            </div>
+        </div>
+    </div>
+</div>
+ 
     
