@@ -313,7 +313,7 @@ function viewform(ID){
                 $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                 $('#viewAcademicYear').html(data.AcademicYear=="" ? "&nbsp;" : data.AcademicYear);
                 $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp" : data.Cre);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
