@@ -3,7 +3,7 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="row">
                         <div class="col-6"> 
-                            <h3>Course Name</h3>
+                            <h3>Course Names</h3>
                          </div>
                          <div class="col-6" style="text-align: right;"> 
                             <button class="btn-save" onclick="addform()">New</button>
@@ -14,33 +14,30 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="transactions-table table">
                         <div class="table">
-                            <table id="example" class="table" style="width:100%">
+                            <table id="listTable" class="table" style="width:100%">
                                 <thead>
                                     <tr>
-                                        <th>Code</th>
+                                        <th style="width:150px">Code</th>
                                         <th>Course Name</th>
                                         <th>Course Type</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
+                                        <th>Department</th>
+                                        <th style="width:50px">Status</th>
+                                        <th style="width:100px"></th>
                                     </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
+                                </thead>                                     
+                                <tbody id="tbl_content">
+                                    <tr>
+                                        <td colspan='4'>
+                                            <?php echo loadingText("Loading Course Names");?>
+                                        </td>
+                                    </tr>
+                                </tbody>
                             </table>
                         </div>
                     </div>
                 </div>
             </div>
-            </div>
+        </div>
 </div>
 
 
@@ -48,35 +45,44 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">New Course</h5>
+                <h5 class="modal-title" id="exampleModalLabel">New Course Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+                <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                 <div class="row">
+                     <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErrCode" class="error_msg" style="color: red;"></span>
                     </div>
-                    <div class="col-12">
-                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CourseType" id="CourseType" onchange="clearInput('CourseType')">
-                            <option value="0">Select Course Type</option>
-                            <option value="1">Course Type 1</option>
-                         </select>
-                        <span id="ErrCourseType" class="error_msg" style="color: red;"></span>
-                    </div>
                     <div class="col-12">
                         <label class="form-label">Course Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="CourseName" name="CourseName" placeholder="Course Name" value="" onkeypress="clearInput('CourseName')">
                         <span id="ErrCourseName" class="error_msg" style="color: red;"></span>
                     </div>
+                    <div class="col-12">
+                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
+                         <select class="form-select form-select-sm" name="CourseTypeID" id="CourseTypeID" onchange="clearInput('CourseTypeID')">
+                            <option value="0">Select Course Type</option>
+                         </select>
+                        <span id="ErrCourseTypeID" class="error_msg" style="color: red;"></span>
+                    </div>
+                    <div class="col-12">
+                        <label class="form-label">Department</label><span style='color:red'>*</span>
+                         <select class="form-select form-select-sm" name="DepartmentID" id="DepartmentID" onchange="clearInput('DepartmentID')">
+                            <option value="0">Select Department</option>
+                         </select>
+                        <span id="ErrDepartmentID" class="error_msg" style="color: red;"></span>
+                    </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
                         <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -90,42 +96,52 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Edit Course</h5>
+                <h5 class="modal-title" id="exampleModalLabel">Edit Course Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+                 <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                 <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                     <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>"  onkeypress="clearInput('editCode')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value=""  onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
-                    </div>
-                     <div class="col-12">
-                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CourseType" id="editCourseType" value="<?php echo $data[0]['CourseType'];?>"  onchange="clearInput('editCourseType')">
-                         <option value="0">Select Course Type</option>
-                         <option value="1">Course Type 1</option>
-                         </select>
-                        <span id="ErreditCourseType" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Course Name</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCourseName" name="CourseName" placeholder="Course Name" value="<?php echo $data[0]['CourseName'];?>" onkeypress="clearInput('editCourseName')">
+                        <input class="form-control form-control-sm" type="text" id="editCourseName" name="CourseName" placeholder="Course Name" value="" onkeypress="clearInput('editCourseName')">
                         <span id="ErreditCourseName" class="error_msg" style="color: red;"></span>
                     </div>
+                    <div class="col-12">
+                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
+                         <select class="form-select form-select-sm" name="CourseTypeID" id="editCourseTypeID" value="" onchange="clearInput('editCourseTypeID')">
+                            <option value="0">Select Course Type</option>
+                         </select>
+                        <span id="ErreditCourseTypeID" class="error_msg" style="color: red;"></span>
+                    </div> 
+                    <div class="col-12">
+                        <label class="form-label">Department</label><span style='color:red'>*</span>
+                         <select class="form-select form-select-sm" name="DepartmentID" id="editDepartmentID" value="" onchange="clearInput('editDepartmentID')">
+                            <option value="0">Select Department</option>
+                         </select>
+                        <span id="ErreditDepartmentID" class="error_msg" style="color: red;"></span>
+                    </div>
                     <div class="col-sm-6">
-                        <label class="form-label">Status</label>
-                        <select name="IsActive" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                        <label class="form-label">Status</label>                           
+                        <select name="Status" id="editStatus" class="form-select form-select-sm">
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="editRemarks_Err()">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -139,34 +155,38 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">View Course</h5>
+                <h5 class="modal-title" id="exampleModalLabel">View Course Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
                 <div class="row">
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
-                    </div>
-                    <div class="col-sm-12">
-                        <div style="font-weight: bold;">Course Type</div>
-                        <?php echo $data[0]['CourseType'];?>
+                         <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Course Name</div>
-                        <?php echo $data[0]['CourseName'];?>
+                         <div id="viewCourseName"></div>
+                    </div>
+                    <div class="col-sm-12">
+                        <div style="font-weight: bold;">Course Type</div>
+                         <div id="viewCourseTypeID"></div>
+                    </div>
+                    <div class="col-sm-12">
+                        <div style="font-weight: bold;">Department</div>
+                         <div id="viewDepartmentID"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                         <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['Status'];?>
+                         <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                         <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
@@ -176,6 +196,7 @@
         </div>                                                                                                                     
     </div>
 </div>
+
 <div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
@@ -185,32 +206,71 @@
                 </div>
                 <h3 class="title">Success.</h3>  
                  <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
-            </div>
+            </div>            
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
-      
+
+
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=macoul","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.CourseName + '</td>' 
+                            + '<td>' + data.CourseType + '</td>' 
+                            + '<td>' + data.Department + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macoul\',\''+data.CourseName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
+
 function addform(){
+    listCourseTypes("0","CourseTypeID");
+    listDepartments("0","DepartmentID");
         $('#confirmationtoadd').modal("show"); 
         $('#Code').val(""); 
         $('#CourseName').val("");
         $('#Remarks').val("");
-        $('#CourseType').val("0");
+        $('#CourseTypeID').val("0");
+        $('#DepartmentID').val("0");
         
         $('#ErrCode').html("");
         $('#ErrCourseName').html(""); 
-        $('#ErrCourseType').html(""); 
+        $('#ErrDepartmentID').html(""); 
+        $('#ErrCourseTypeID').html(""); 
         $('#ErrRemarks').html(""); 
         
         $("#Code").removeClass("highlight_error");  
         $("#CourseName").removeClass("highlight_error");  
-        $("#CourseType").removeClass("highlight_error");  
+        $("#DepartmentID").removeClass("highlight_error");  
+        $("#CourseTypeID").removeClass("highlight_error");  
         $("#Remarks").removeClass("highlight_error");    
        
 }
@@ -225,14 +285,16 @@ function add(){
          $("#Code").removeClass("highlight_error");
             $('#ErrCode').html(""); 
     }
-    if ($('#CourseType').val()=="0"){
-            $('#ErrCourseType').html("Please select Course Type");
-           $("#CourseType").addClass("highlight_error");
+    
+    if ($('#CourseTypeID').val()=="0"){
+            $('#ErrCourseTypeID').html("Please select Course Type");
+           $("#CourseTypeID").addClass("highlight_error");
            error++;
     }  else {
-            $("#CourseType").removeClass("highlight_error");
-            $('#ErrCourseType').html(""); 
+            $("#CourseTypeID").removeClass("highlight_error");
+            $('#ErrCourseTypeID').html(""); 
     } 
+    
     if ($('#CourseName').val()==""){
             $('#ErrCourseName').html("Please enter Course Name");
           $("#CourseName").addClass("highlight_error");
@@ -240,27 +302,70 @@ function add(){
     }  else {
              $("#CourseName").removeClass("highlight_error");
             $('#ErrCourseName').html(""); 
+    }
+    if ($('#DepartmentID').val()==""){
+            $('#ErrDepartmentID').html("Please enter Department");
+          $("#DepartmentID").addClass("highlight_error");
+            error++;
+    }  else {
+             $("#DepartmentID").removeClass("highlight_error");
+            $('#ErrDepartmentID').html(""); 
     } 
-     if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
+      if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=macoul",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
     } 
 }
 
-function editform(){
+function editform(ID){
      $('#confirmationtoedit').modal("show"); 
      $('#ErreditCode').html("");
      $('#ErreditCourseName').html(""); 
-     $('#ErreditCourseType').html(""); 
+     $('#ErreditDepartmentID').html(""); 
+     $('#ErreditCourseTypeID').html(""); 
      $('#ErreditRemarks').html(""); 
      $("#editCode").removeClass("highlight_error");  
      $("#editCourseName").removeClass("highlight_error");  
-     $("#editCourseType").removeClass("highlight_error");  
+     $("#editCourseTypeID").removeClass("highlight_error");  
      $("#editRemarks").removeClass("highlight_error");
-}
+      $.post(URL+ "webservice.php?action=g&method=macoul&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+             _CourseTypeID="";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editDepartment').val(data.Department);
+                $('#editCourseName').val(data.CourseName);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+                _CourseTypeID=data.CourseTypeID;
+                _DepartmentID=data.DepartmentID;
+            }); 
+            if (obj.data.length>0)    {
+                 listCourseTypes(_CourseTypeID,"editCourseTypeID")
+                 listDepartments(_DepartmentID,"editDepartmentID")
+            }  
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });
+}                                                                                        
 
-function edit(){
-     var error = 0;
+
+function edit(ID){
+    var error = 0;
+    
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Course Code");
             $("#editCode").addClass("highlight_error"); 
@@ -269,13 +374,13 @@ function edit(){
             $("#editCode").removeClass("highlight_error"); 
             $('#ErreditCode').html(""); 
     }
-     if ($('#editCourseType').val()=="0"){
-            $('#ErreditCourseType').html("Please select Course Type");
-            $("#editCourseType").addClass("highlight_error"); 
+     if ($('#editCourseTypeID').val()=="0"){
+            $('#ErreditCourseTypeID').html("Please select Course Type");
+            $("#editCourseTypeID").addClass("highlight_error"); 
            error++;
     }  else {
-            $("#editCourseType").removeClass("highlight_error"); 
-            $('#ErreditCourseType').html(""); 
+            $("#editCourseTypeID").removeClass("highlight_error"); 
+            $('#ErreditCourseTypeID').html(""); 
     } 
     if ($('#editCourseName').val()==""){
             $('#ErreditCourseName').html("Please enter Course Name");
@@ -284,23 +389,83 @@ function edit(){
     }  else {
             $("#editCourseName").removeClass("highlight_error"); 
             $('#ErreditCourseName').html(""); 
-    }  
-     if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
     } 
-   
-}
-
-function viewform(){
-     $('#confirmationtoview').modal("show"); 
+    if ($('#editDepartmentID').val()==""){
+            $('#ErreditDepartmentID').html("Please enter Department");
+            $("#editDepartment").addClass("highlight_error"); 
+            error++;
+    }  else {
+            $("#editDepartmentID").removeClass("highlight_error"); 
+            $('#ErreditDepartmentID').html(""); 
+    }  
+     if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=macoul",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+     } 
 }
 
 
-function dashboard()  {
-  location.href='dashboard.php';                                                              
+function viewform(ID){
+     $('#confirmationtoview').modal("show");
+      $.post(URL+ "webservice.php?action=g&method=macoul&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCourseName').html(data.CourseName=="" ? "&nbsp" : data.CourseName);
+                $('#viewDepartmentID').html(data.Department=="" ? "&nbsp" : data.Department);
+                $('#viewCourseTypeID').html(data.CourseType=="" ? "&nbsp" : data.CourseType);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+        }  
+  })  
 }
 
+function listCourseTypes(selected,selectboxID) {
+    $.post(URL+ "webservice.php?action=lac&method=mactl","",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "<option value='0'> Select Course Type</option>";
+            $.each(obj.data, function (index, data) {
+                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.CourseType+'</option>';
+            });   
+                $('#'+selectboxID).html(html);
+        } else {
+            $('#ErrCommon').html( errorcontent(obj.message));
+        }
+    })
+}
+
+function listDepartments(selected,selectboxID) {
+    $.post(URL+ "webservice.php?action=lac&method=madl","",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "<option value='0'> Select Department</option>";
+            $.each(obj.data, function (index, data) {
+                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.Department+'</option>';
+            });   
+                $('#'+selectboxID).html(html);
+        } else {
+            $('#ErrCommon').html( errorcontent(obj.message));
+        }
+    })
+}
+ 
 //Character Limitations
 
 /*Alphanumeric without space*/
