@@ -210,6 +210,7 @@ function addform(){
     $('#ErrCode').html("");
     $('#ErrDepartment').html(""); 
     $('#ErrRemarks').html("");
+    $('#ErrCommon').html("");
          
     $("#Code").removeClass("highlight_error");   
     $("#Department").removeClass("highlight_error");   
@@ -259,6 +260,7 @@ function editform(ID){
      $('#ErreditCode').html("");
      $('#ErreditDepartment').html(""); 
      $('#ErreditRemarks').html("");
+     $('#ErreditCommon').html("");
     
       $("#editCode").removeClass("highlight_error");   
       $("#editDepartment").removeClass("highlight_error");   
