@@ -34,7 +34,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">New Exam</h5>
+                <h5 class="modal-title" id="exampleModalLabel">New Examination</h5>
                  <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -47,7 +47,7 @@
                         <span id="ErrCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
-                        <label class="form-label">Exam Name</label><span style='color:red'>*</span>
+                        <label class="form-label">Examination Name</label><span style='color:red'>*</span>
                          <input class="form-control form-control-sm" type="text" name="ExamName" id="ExamName" placeholder="Exam Name" onkeypress="clearInput('ExamName')">
                         <span id="ErrExamName" class="error_msg" style="color: red;"></span>
                     </div>
@@ -71,7 +71,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Edit Exam</h5>
+                <h5 class="modal-title" id="exampleModalLabel">Edit Examination</h5>
                  <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -85,7 +85,7 @@
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
-                        <label class="form-label">Exam Name</label><span style='color:red'>*</span>
+                        <label class="form-label">Examination Name</label><span style='color:red'>*</span>
                          <input class="form-control form-control-sm" type="text" name="ExamName" id="editExamName" placeholder="Exam Name" value="" onkeypress="clearInput('editExamName')">
                         <span id="ErreditExamName" class="error_msg" style="color: red;"></span>
                     </div>
@@ -116,7 +116,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">View Exam</h5>
+                <h5 class="modal-title" id="exampleModalLabel">View Examination</h5>
                  <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -126,7 +126,7 @@
                          <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
-                        <div style="font-weight: bold;">Exam Name</div>
+                        <div style="font-weight: bold;">Examination Name</div>
                          <div id="viewExamName"></div>
                     </div>
                     <div class="col-sm-12">
@@ -209,6 +209,7 @@ function addform(){
      $('#ErrCode').html("");
      $('#ErrExamName').html(""); 
      $('#ErrRemarks').html("");
+     $('#ErrCommon').html("");
       
      $("#Code").removeClass("highlight_error");   
      $("#ExamName").removeClass("highlight_error");   
@@ -252,7 +253,8 @@ function editform(ID){
      
      $('#ErreditCode').html("");
      $('#ErreditExamName').html(""); 
-     $('#ErreditRemarks').html("");
+     $('#ErreditRemarks').html("");   
+     $('#ErreditCommon').html("");
      
      $("#editCode").removeClass("highlight_error");   
      $("#editExamName").removeClass("highlight_error");   
