@@ -97,7 +97,7 @@
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
@@ -148,6 +148,7 @@
         </div>                                                                                                                     
     </div>
 </div>
+
 <div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
@@ -328,11 +329,6 @@ function viewform(ID){
   }) 
 }
 
-
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
- 
 //Character Limitations
 
 /*Alphanumeric without space*/
