@@ -1,9 +1,9 @@
-            <div class="user-dashboard">
+                       <div class="user-dashboard">
                 <div class="container">
                 <div class="col-xl-12 col-lg-12">
                     <div class="row">
                         <div class="col-6"> 
-                            <h3>Subject</h3>
+                            <h3>Subject Names</h3>
                          </div>
                          <div class="col-6" style="text-align: right;"> 
                             <button class="btn-save" onclick="addform()">New</button>
@@ -14,26 +14,22 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="transactions-table table">
                         <div class="table">
-                            <table id="example" class="table" style="width:100%">
+                            <table id="listTable" class="table" style="width:100%">
                                 <thead>
                                     <tr>
-                                        <th>Code</th>
-                                        <th>University Subject Code</th>
+                                        <th style="width:150px">Code</th>
                                         <th>Subject Name</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
+                                        <th>University Subject Code</th>
+                                        <th style="width:50px">Status</th>
+                                        <th style="width:100px"></th>
                                     </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
+                                </thead>                                     
+                                <tbody id="tbl_content"> <tr>
+                                    <td colspan='5'>
+                                            <?php echo loadingText("Loading Subject Names");?>
+                                        </td>
+                                    </tr>
+                                </tbody>
                             </table>
                         </div>
                     </div>
@@ -41,32 +37,18 @@
             </div>
             </div>
 </div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                <button type="button" class="btn-close" data-dismiss="modal"></button>
-            </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
-    </div>
-</div>
 
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">New Subject</h5>
+                <h5 class="modal-title" id="exampleModalLabel">New Subject Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+            <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                 <div class="row">
+                    <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
@@ -89,6 +71,7 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+            </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -102,40 +85,44 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Edit Subject</h5>
+                <h5 class="modal-title" id="exampleModalLabel">Edit Subject Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+            <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                    <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-6"></div>
                     <div class="col-6">
                         <label class="form-label">University Subject Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editUniversitySubjectCode" name="UniversitySubjectCode" placeholder="University Subject Code" value="<?php echo $data[0]['UniversitySubjectCode'];?>" onkeypress="clearInput('editUniversitySubjectCode')">
+                        <input class="form-control form-control-sm" type="text" id="editUniversitySubjectCode" name="UniversitySubjectCode" placeholder="University Subject Code" value="" onkeypress="clearInput('editUniversitySubjectCode')">
                         <span id="ErreditUniversitySubjectCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">Subject Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="SubjectName" id="editSubjectName" placeholder="Subject Name" value="<?php echo $data[0]['SubjectName'];?>" onkeypress="clearInput('editSubjectName')">
+                         <input class="form-control form-control-sm" type="text" name="SubjectName" id="editSubjectName" placeholder="Subject Name" value="" onkeypress="clearInput('editSubjectName')">
                         <span id="ErreditSubjectName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+            </form>
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -149,39 +136,39 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">View Subject</h5>
+                <h5 class="modal-title" id="exampleModalLabel">View Subject Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
                 <div class="row">
                    <div class="col-sm-12">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
+                        <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">University Subject Code</div>
-                        <?php echo $data[0]['UniversitySubjectCode'];?>
+                        <div id="viewUniversitySubjectCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Subject Name</div>
-                        <?php echo $data[0]['SubjectName'];?>
+                        <div id="viewSubjectName"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                        <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['Status'];?>
+                        <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                        <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -194,24 +181,61 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
-      
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=masul","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.SubjectName + '</td>'
+                            + '<td>' + data.UniversitySubjectCode + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'masul\',\''+data.SubjectName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
+
 function addform(){
          $('#confirmationtoadd').modal("show"); 
          $('#Code').val(""); 
          $('#UniversitySubjectCode').val(""); 
          $('#SubjectName').val(""); 
          $('#Remarks').val(""); 
+         
+         $('#ErrCode').html("");
+         $('#ErrUniversitySubjectCode').html(""); 
+         $('#ErrSubjectName').html(""); 
+         $('#ErrRemarks').html("");
+     
          $("#Code").removeClass("highlight_error"); 
          $("#UniversitySubjectCode").removeClass("highlight_error"); 
          $("#SubjectName").removeClass("highlight_error"); 
@@ -244,22 +268,53 @@ function add(){
             $("#SubjectName").removeClass("highlight_error"); 
             $('#ErrSubjectName').html(""); 
     } 
-     if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+    if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=masul",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   } 
    
 }
 
-function editform(){
+function editform(ID){
      $('#confirmationtoedit').modal("show"); 
+     
+     $('#ErreditCode').html("");
+     $('#ErreditUniversitySubjectCode').html(""); 
+     $('#ErreditSubjectName').html(""); 
+     $('#ErreditRemarks').html("");
+         
       $("#editCode").removeClass("highlight_error"); 
       $("#editUniversitySubjectCode").removeClass("highlight_error"); 
       $("#editSubjectName").removeClass("highlight_error"); 
       $("#editRemarks").removeClass("highlight_error");
+       $.post(URL+ "webservice.php?action=g&method=masul&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editUniversitySubjectCode').val(data.UniversitySubjectCode);
+                $('#editID').val(data.ID);
+                $('#editSubjectName').val(data.SubjectName);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+            });   
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });
 }
 
-function edit(){
+function edit(ID){
     var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -285,23 +340,42 @@ function edit(){
             $("#editSubjectName").removeClass("highlight_error"); 
             $('#ErreditSubjectName').html(""); 
     } 
-     if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
-    }
-  
+     if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=masul",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+       }
 }
 
-function viewform(){
+function viewform(ID){
      $('#confirmationtoview').modal("show"); 
+     $.post(URL+ "webservice.php?action=g&method=masul&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewUniversitySubjectCode').html(data.UniversitySubjectCode=="" ? "&nbsp;" : data.UniversitySubjectCode);
+                $('#viewSubjectName').html(data.SubjectName=="" ? "&nbsp" : data.SubjectName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  })
 }
 
-
-
- 
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
  
 //Character Limitations
  
