@@ -182,7 +182,7 @@
 
 function list() {
       $('#Success').modal("hide");
-    $.post(URL+ "webservice.php?action=l&method=macnl","",function(data){
+    $.post(URL+ "webservice.php?action=l&method=macoll","",function(data){
       var obj = JSON.parse(data);
         if (obj.status=="success") {
             var html = "";
@@ -196,7 +196,7 @@ function list() {
                             + '<td style="text-align:right">' 
                                 + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                                 + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
-                                + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macnl\',\''+data.CollegeName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                                + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macoll\',\''+data.CollegeName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                             + '</td>'
                          + '</tr>'
                       + '</tr>';
@@ -264,7 +264,7 @@ function add(){
   
      if(error==0){
         var param = $('#frm_create').serialize();
-        $.post(URL+"webservice.php?action=a&method=macnl",param,function(data){
+        $.post(URL+"webservice.php?action=a&method=macoll",param,function(data){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoadd').modal("hide"); 
@@ -286,7 +286,7 @@ function editform(ID){
      $("#editCollegeName").removeClass("highlight_error"); 
      $("#editPlaceName").removeClass("highlight_error"); 
      $("#editRemarks").removeClass("highlight_error");
-      $.post(URL+ "webservice.php?action=g&method=macnl&ID="+ID,"",function(data){
+      $.post(URL+ "webservice.php?action=g&method=macoll&ID="+ID,"",function(data){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             var html = "";
@@ -333,7 +333,7 @@ function edit(ID){
     } 
       if(error==0){
         var param = $('#frm_edit').serialize();
-        $.post(URL+"webservice.php?action=u&method=macnl",param,function(data){
+        $.post(URL+"webservice.php?action=u&method=macoll",param,function(data){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoedit').modal("hide");
@@ -348,15 +348,15 @@ function edit(ID){
 
 function viewform(ID){
      $('#confirmationtoview').modal("show"); 
-       $.post(URL+ "webservice.php?action=g&method=macnl&ID="+ID,"",function(data){
+       $.post(URL+ "webservice.php?action=g&method=macoll&ID="+ID,"",function(data){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewCollegeName').html(data.CollegeName);
-                $('#viewPlaceName').html(data.PlaceName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCollegeName').html(data.CollegeName=="" ? "&nbsp;" : data.CollegeName);
+                $('#viewPlaceName').html(data.PlaceName=="" ? "&nbsp;" : data.PlaceName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
