@@ -20,7 +20,7 @@
                     </thead>                                     
                     <tbody id="tbl_content">
                         <tr>
-                            <td colspan='4'>
+                            <td colspan='5'>
                                 <?php echo loadingText("Loading Institution Names");?>
                             </td>
                         </tr>
@@ -205,7 +205,7 @@
             });
             if(obj.data.length==0){
             html += '<tr>'
-                + '<td colspan="4" style="text-align: center;background:#fff !important">No data found</td>'
+                + '<td colspan="5" style="text-align: center;background:#fff !important">No data found</td>'
                 + '</tr>'
             }   
             $('#tbl_content').html(html);
@@ -353,11 +353,11 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewInstitutionName').html(data.InstitutionName);
-                $('#viewPlaceName').html(data.PlaceName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewInstitutionName').html(data.InstitutionName=="" ? "&nbsp;" : data.InstitutionName);
+                $('#viewPlaceName').html(data.PlaceName=="" ? "&nbsp;" : data.PlaceName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
