@@ -34,7 +34,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">New Qualification</h5>
+                <h5 class="modal-title" id="exampleModalLabel">New Qualification (Degree)</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -71,7 +71,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Edit Qualification</h5>
+                <h5 class="modal-title" id="exampleModalLabel">Edit Qualification  (Degree)</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -116,7 +116,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">View Scheme Name</h5>
+                <h5 class="modal-title" id="exampleModalLabel">View Qualification (Degree)</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -127,7 +127,7 @@
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Qualification (Degree)</div>
-                        <div id="view<div id="viewCode"></div>"></div>
+                        <div id="viewQualificationName"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
@@ -141,11 +141,12 @@
                         <div style="font-weight: bold;">Created On</div>
                         <div id="viewCreatedOn"></div>
                     </div>
-                </div>
-            </div>
-            <div class="modal-footer"> 
+                     <div class="modal-footer"> 
                  <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
+                </div>
+            </div>
+           
         </div>                                                                                                                     
     </div>
 </div>
@@ -311,10 +312,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewQualificationName').html(data.QualificationName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewQualificationName').html(data.QualificationName=="" ? "&nbsp;" : data.QualificationName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
