@@ -16,7 +16,7 @@
                             <th>Place Name</th>
                             <th style="width:50px">Status</th>
                             <th style="width:100px"></th>
-                        tr>
+                        </tr>
                     </thead>                                     
                     <tbody id="tbl_content">
                         <tr>
@@ -353,11 +353,11 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewSchoolName').html(data.SchoolName);
-                $('#viewPlaceName').html(data.PlaceName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewSchoolName').html(data.SchoolName=="" ? "&nbsp;" : data.SchoolName);
+                $('#viewPlaceName').html(data.PlaceName=="" ? "&nbsp;" : data.PlaceName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
