@@ -106,7 +106,7 @@
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
-                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
+                 <button type="button"  onclick="edit()" class="btn-save">Update</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -277,7 +277,7 @@ function editform(ID){
   });
 }                                                                                                 
 
-function edit(ID){
+function edit(ID) {
      var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -286,7 +286,7 @@ function edit(ID){
     }  else {
          $("#editCode").removeClass("highlight_error"); 
             $('#ErreditCode').html(""); 
-    }      error++;
+    }     
      if ($('#editStaffType').val()==""){
             $('#ErreditStaffType').html("Please enter Staff Type");
            $("#editStaffType").addClass("highlight_error"); 
@@ -295,7 +295,8 @@ function edit(ID){
          $("#editStaffType").removeClass("highlight_error"); 
             $('#ErreditStaffType').html(""); 
     } 
-      if(error==0){
+     
+         if(error==0){
        var param = $('#frm_edit').serialize();
         $.post(URL+"webservice.php?action=u&method=macstl",param,function(data){
         var obj = JSON.parse(data); 
@@ -306,8 +307,7 @@ function edit(ID){
             $('#ErreditCommon').html(print_inlineError(obj.message));
         }
     });
-   }
-   
+   }  
 }
 
 function viewform(ID){
@@ -316,10 +316,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewStaffType').html(data.StaffType);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewStaffType').html(data.StaffType=="" ? "&nbsp;" : data.StaffType);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
