@@ -20,7 +20,7 @@
                     </thead>                                     
                     <tbody id="tbl_content">
                         <tr>
-                            <td colspan='4'>
+                            <td colspan='5'>
                                 <?php echo loadingText("Loading University Names");?>
                             </td>
                         </tr>
@@ -87,8 +87,8 @@
                 <div class="row">
                 <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
@@ -204,7 +204,7 @@ function list() {
             });
             if(obj.data.length==0){
             html += '<tr>'
-                + '<td colspan="4" style="text-align: center;background:#fff !important">No data found</td>'
+                + '<td colspan="5" style="text-align: center;background:#fff !important">No data found</td>'
                 + '</tr>'
             }   
             $('#tbl_content').html(html);
@@ -352,11 +352,11 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewUniversityName').html(data.UniversityName);
-                $('#viewPlaceName').html(data.PlaceName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewUniversityName').html(data.UniversityName=="" ? "&nbsp;" : data.UniversityName);
+                $('#viewPlaceName').html(data.PlaceName=="" ? "&nbsp;" : data.PlaceName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
