@@ -66,7 +66,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">New Country</h5>
+                <h5 class="modal-title" id="exampleModalLabel">New Country Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -115,7 +115,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Edit Country</h5>
+                <h5 class="modal-title" id="exampleModalLabel">Edit Country Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -170,7 +170,7 @@
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">View Country</h5>
+                <h5 class="modal-title" id="exampleModalLabel">View Country Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
@@ -288,7 +288,7 @@ function list() {
                              + '<td style="text-align:right">' 
                                 + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                                + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
-                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macnl\',\''+data.CountryName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mccol\',\''+data.CountryName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                                + '</td>'
                              + '</tr>' 
                       + '</tr>';
@@ -479,12 +479,12 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewCountryName').html(data.CountryName);
-                $('#viewInternationalCode').html(data.InternationalCode);
-                $('#viewTelecomCode').html(data.TelecomCode);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCountryName').html(data.CountryName=="" ? "&nbsp;" : data.CountryName);
+                $('#viewInternationalCode').html(data.InternationalCode=="" ? "&nbsp;" : data.InternationalCode);
+                $('#viewTelecomCode').html(data.TelecomCode=="" ? "&nbsp;" : data.TelecomCode);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
@@ -501,7 +501,7 @@ function viewform(ID){
  
 
 /*Alphanumeric without space*/
-var arr = ["Code","editCode","InternationalCode","editInternationalCode","TelecomCode","editTelecomCode"];
+var arr = ["Code","editCode"];
 for (var i=0; i<arr.length; i++) {
     if ($('#'+arr[i]).length){
         document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
@@ -528,6 +528,70 @@ for (var i=0; i<arr.length; i++) {
     } 
 }
 
+/* Alphanumeric without space and allowed +,-*/ 
+var arr = ["TelecomCode","editTelecomCode"];
+for (var i=0; i<arr.length; i++) {
+    if ($('#'+arr[i]).length){
+        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
+            var keyCode = e.keyCode || e.which;
+            console.log(e.keyCode);
+            if (e.ctrlKey || e.altKey) {
+                e.preventDefault();
+            } else {
+                var notallowkeys = [173,16,48,49,50,51,52,53,54,55,56,57,16,188,190,191,59,222,220,219,221,61,192,111,106,109,107,46,110,190,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90];
+               var _allowedkeys = [61]; //when press shift
+               var allowedkeys  = [32,173,9,8,46,35,36,37,38,39,40,48,49,50,51,52,53,54,55,56,57,103,104,105,100,101,102,97,98,99,96];
+               if (e.shiftKey) {
+                if (_allowedkeys.includes(keyCode)) {
+                     notallowkeys
+                } else {
+                    if (notallowkeys.includes(keyCode)) {
+                        e.preventDefault();
+                    }
+                }
+            } else {
+                if (!(allowedkeys.includes(keyCode))) {
+                    e.preventDefault();
+                }  
+            }
+            }
+        });
+        $('#'+arr[i]).on("cut copy paste",function(e){
+            e.preventDefault();
+        });  
+    } 
+}
+
+
+
+var arr = ["InternationalCode","editInternationalCode"];
+for (var i=0; i<arr.length; i++) {
+    if ($('#'+arr[i]).length){
+        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
+            var keyCode = e.keyCode || e.which;
+            if (e.ctrlKey || e.altKey) {
+                e.preventDefault();
+            } else {
+                 var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
+                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
+                if (e.shiftKey) {
+                    if (notallowkeys.includes(keyCode)) {
+                        e.preventDefault();
+                    }
+                } else {
+                    if (!(allowedkeys.includes(keyCode))) {
+                        e.preventDefault();
+                    }
+                }
+            }
+        });
+        $('#'+arr[i]).on("cut copy paste",function(e){
+            e.preventDefault();
+        });  
+    } 
+}
+
+
 
 /* Alphabets Space Dot only correct */ 
 var arr = ["CountryName","editCountryName"];
