@@ -200,12 +200,12 @@
 
  function list() {
       $('#Success').modal("hide");
-    $.post(URL+ "webservice.php?action=l&method=mccnl","",function(data){
+    $.post(URL+ "webservice.php?action=l&method=mccorl","",function(data){
       var obj = JSON.parse(data);
         if (obj.status=="success") {
             var html = "";
             $.each(obj.data, function (index, data) {
-                html += '<tr>'
+                 html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                             + '<td>' + data.Code + '</td>'
                             + '<td>' + data.CurrencyName + '</td>' 
                             + '<td>' + data.CurrencySymbol + '</td>' 
@@ -291,7 +291,7 @@ function add(){
   
      if(error==0){
         var param = $('#frm_create').serialize();
-        $.post(URL+"webservice.php?action=a&method=mccnl",param,function(data){
+        $.post(URL+"webservice.php?action=a&method=mccorl",param,function(data){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoadd').modal("hide"); 
@@ -314,7 +314,7 @@ function editform(ID){
      $("#editCurrencyShortName").removeClass("highlight_error"); 
      $("#editCurrencySymbol").removeClass("highlight_error"); 
      $("#editRemarks").removeClass("highlight_error");
-      $.post(URL+ "webservice.php?action=g&method=mccnl&ID="+ID,"",function(data){
+      $.post(URL+ "webservice.php?action=g&method=mccorl&ID="+ID,"",function(data){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             var html = "";
@@ -369,7 +369,7 @@ function edit(ID){
     } 
       if(error==0){
         var param = $('#frm_edit').serialize();
-        $.post(URL+"webservice.php?action=u&method=mccnl",param,function(data){
+        $.post(URL+"webservice.php?action=u&method=mccorl",param,function(data){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoedit').modal("hide");
@@ -384,15 +384,15 @@ function edit(ID){
 
 function viewform(ID){
      $('#confirmationtoview').modal("show"); 
-       $.post(URL+ "webservice.php?action=g&method=mccnl&ID="+ID,"",function(data){
+       $.post(URL+ "webservice.php?action=g&method=mccorl&ID="+ID,"",function(data){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewCurrencyName').html(data.CurrencyName);
-                $('#viewCurrencyShortName').html(data.CurrencyShortName);
-                $('#viewCurrencySymbol').html(data.CurrencySymbol);
-                $('#viewRemarks').html(data.Remarks);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCurrencyName').html(data.CurrencyName=="" ? "&nbsp;" : data.CurrencyName);
+                $('#viewCurrencyShortName').html(data.CurrencyShortName=="" ? "&nbsp;" : data.CurrencyShortName);
+                $('#viewCurrencySymbol').html(data.CurrencySymbol=="" ? "&nbsp;" : data.CurrencySymbol);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                 $('#viewCreatedOn').html(data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
