@@ -14,49 +14,29 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="transactions-table table">
                         <div class="table">
-                            <table id="example" class="table" style="width:100%">
+                            <table id="listTable" class="table" style="width:100%">
                                 <thead>
                                     <tr>
-                                        <th>Code</th>
+                                        <th style="width:150px">Code</th>
                                         <th>District Name</th>
                                         <th>State Name</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
+                                        <th>Country Name</th>
+                                        <th style="width:50px">Status</th>
+                                        <th style="width:100px"></th>
                                     </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
+                                </thead>                                     
+                                <tbody id="tbl_content"> <tr>
+                                    <td colspan='6'>
+                                            <?php echo loadingText("Loading District Names");?>
+                                        </td>
+                                    </tr>
+                                </tbody>
                             </table>
                         </div>
                     </div>
                 </div>
             </div>
-            </div>
-</div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                 <button type="button" class="btn-close" data-dismiss="modal"></button>
-            </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
-    </div>
+      </div>
 </div>
 
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
@@ -67,31 +47,31 @@
                  <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+                 <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                 <div class="row">
+                     <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="Code" name="ode" placeholder="Code" value="" onkeypress="clearInput('Code')">
+                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErrCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="CountryName" onchange="clearInput('CountryName')">
-                            <option value="0">Select Country Name</option>
-                            <option value="1">Country Name</option>
+                          <select class="form-select form-select-sm" name="CountryNameID" id="CountryNameID" onchange="clearInput('CountryNameID');listStateNames('frm_create','StateNameID','0')">
+                            <option value="0">Select Country Name</option>                            
                          </select>
-                        <span id="ErrCountryName" class="error_msg" style="color: red;"></span>
+                        <span id="ErrCountryNameID" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="StateName" id="StateName" onchange="clearInput('StateName')">
+                            <select class="form-select form-select-sm" name="StateNameID" id="StateNameID" onchange="clearInput('StateNameID');">
                             <option value="0">Select State Name</option>
-                            <option value="1">State Name</option>
                          </select>
-                        <span id="ErrStateName" class="error_msg" style="color: red;"></span>
+                        <span id="ErrStateNameID" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">District Name</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="DistrictName" name="DistrictName" placeholder="District Name" value="" onkeypress="clearInput('DistrictName')">
+                        <input class="form-control form-control-sm" type="text" id="DistrictName" name="DistrictName" placeholder="District Name" value="" onchange="clearInput('DistrictName')">
                         <span id="ErrDistrictName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
@@ -100,7 +80,8 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
-            </div>
+                </form>
+            </div>                                           
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                  <button type="button" href="javascript:void(0)" onclick="add()"class="btn-save">Save</button>
@@ -117,46 +98,48 @@
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+                 <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                 <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                     <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="editCountryName" value="<?php echo $data[0]['Country'];?>" onchange="clearInput('editCountryName')">
-                            <option value="0"> Select Country Name</option>
-                            <option value="1"> Country Name</option>
+                         <select class="form-select form-select-sm" name="CountryNameID" id="editCountryNameID" onchange="clearInput('editCountryNameID');;listStateNames('frm_edit','editStateNameID','0')">
+                            <option value="0">Select Country Name</option>
                          </select>
-                        <span id="ErreditCountryName" class="error_msg" style="color: red;"></span>
+                        <span id="ErreditCountryNameID" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="StateName" id="editStateName" value="<?php echo $data[0]['StateName'];?>" onchange="clearInput('editStateName')">
-                            <option value="0"> Select State Name</option>
-                            <option value="1"> State Name</option>
+                         <select class="form-select form-select-sm" name="StateNameID" id="editStateNameID" onchange="clearInput('editStateNameID')">
+                            <option>Select State Name</option>
                          </select>
-                        <span id="ErreditStateName" class="error_msg" style="color: red;"></span>
+                        <span id="ErreditStateNameID" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">District Name</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editDistrictName" name="DistrictName" placeholder="District Name" value="<?php echo $data[0]['DistrictName'];?>" onkeypress="clearInput('editDistrictName')">
+                        <input class="form-control form-control-sm" type="text" id="editDistrictName" name="DistrictName" placeholder="District Name" value="" onkeypress="clearInput('editDistrictName')">
                         <span id="ErreditDistrictName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                </form>
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -177,40 +160,41 @@
                 <div class="row">
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
+                         <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Country Name</div>
-                        <?php echo $data[0]['CountryName'];?>
+                         <div id="viewCountryNameID"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">State Name</div>
-                        <?php echo $data[0]['StateName'];?>
+                         <div id="viewStateNameID"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">District Name</div>
-                        <?php echo $data[0]['DistrictName'];?>
+                         <div id="viewDistrictName"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                         <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['Status'];?>
+                         <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                         <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
 </div>
+
 <div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
@@ -219,64 +203,101 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
-      
+
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=mcdnl","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.DistrictName     + '</td>' 
+                            + '<td>' + data.StateName + '</td>' 
+                            + '<td>' + data.CountryName + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mcdnl\',\''+data.DistrictName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
+
 function addform(){
+listCountryNames("frm_create","CountryNameID","0");
+
+     
     $('#confirmationtoadd').modal("show"); 
     $('#Code').val(""); 
-    $('#StateName').val("0"); 
-    $('#CountryName').val("0"); 
+    $('#StateNameID').val("0"); 
+    $('#CountryNameID').val("0"); 
     $('#DistrictName').val(""); 
     $('#Remarks').val(""); 
     
     $('#ErrCode').html(""); 
-    $('#ErrStateName').html(""); 
-    $('#ErrCountryName').html(""); 
+    $('#ErrStateNameID').html(""); 
+    $('#ErrCountryNameID').html(""); 
     $('#ErrDistrictName').html(""); 
     $('#ErrRemarks').html("");
+    $('#ErrCommon').html("");
     
     $("#Code").removeClass("highlight_error"); 
-    $("#StateName").removeClass("highlight_error"); 
-    $("#CountryName").removeClass("highlight_error"); 
+    $("#StateNameID").removeClass("highlight_error"); 
+    $("#CountryNameID").removeClass("highlight_error"); 
     $("#DistrictName").removeClass("highlight_error"); 
-    $("#Remarks").removeClass("highlight_error"); 
+    $("#Remarks").removeClass("highlight_error");
 }
 
-function add(){
+function add(){                                           
      var error = 0;
        if ($('#Code').val()==""){
             $('#ErrCode').html("Please enter Code");
          $("#Code").addClass("highlight_error"); 
-            error++;
+            error++;                                                                         
     }  else {
         $("#Code").removeClass("highlight_error"); 
             $('#ErrCode').html(""); 
     }
     if ($('#StateName').val()=="0"){
-            $('#ErrStateName').html("Please select State Name");
+            $('#ErrStateName').html("Please Select State Name");
           $("#StateName").addClass("highlight_error"); 
             error++;
     }  else {
-        $("#StateName").removeClass("highlight_error"); 
+            $("#StateName").removeClass("highlight_error"); 
             $('#ErrStateName').html(""); 
     } 
-     if ($('#CountryName').val()=="0"){
-            $('#ErrCountryName').html("Please select Country Name");
-          $("#CountryName").addClass("highlight_error"); 
+     if ($('#CountryNameID').val()=="0"){
+            $('#ErrCountryNameID').html("Please Select Country Name");
+          $("#CountryNameID").addClass("highlight_error"); 
           error++;
     }  else {
-         $("#CountryName").removeClass("highlight_error"); 
-            $('#ErrCountryName').html(""); 
+         $("#CountryNameID").removeClass("highlight_error"); 
+            $('#ErrCountryNameID').html(""); 
     } 
     if ($('#DistrictName').val()==""){
             $('#ErrDistrictName').html("Please enter District Name");
@@ -286,13 +307,22 @@ function add(){
           $("#DistrictName").removeClass("highlight_error"); 
             $('#ErrDistrictName').html(""); 
     } 
-    if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=mcdnl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   } 
 }
 
-function editform(){
+function editform(ID) {
+   
      $('#confirmationtoedit').modal("show"); 
      $('#ErreditCode').html(""); 
      $('#ErreditStateName').html(""); 
@@ -303,10 +333,38 @@ function editform(){
      $("#editStateName").removeClass("highlight_error"); 
      $("#editCountryName").removeClass("highlight_error"); 
      $("#editDistrictName").removeClass("highlight_error"); 
-     $("#editRemarks").removeClass("highlight_error"); 
+     $("#editRemarks").removeClass("highlight_error");
+     $('#ErreditCommon').html("");
+     $.post(URL+ "webservice.php?action=g&method=mcdnl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+             _CountryNameID="";
+             _StateNameID="";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editDistrictName').val(data.DistrictName);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+                _CountryNameID=data.CountryNameID;
+                _StateNameID=data.StateNameID;
+            }); 
+             if (obj.data.length>0)    {
+                 listCountryNames("frm_edit","editCountryNameID",_CountryNameID);
+                 setTimeout(function(){
+                 listStateNames("frm_edit","editStateNameID",_StateNameID);    
+                 },2000);
+                 
+            }  
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });  
 }
 
-function edit(){
+function edit(ID){
       var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -317,7 +375,7 @@ function edit(){
             $('#ErreditCode').html(""); 
     }
      if ($('#editStateName').val()=="0"){
-            $('#ErreditStateName').html("Please select State Name");
+            $('#ErreditStateName').html("Please Select State Name");
          $("#editStateName").addClass("highlight_error"); 
           error++;
     }  else {
@@ -325,7 +383,7 @@ function edit(){
             $('#ErreditStateName').html(""); 
     } 
       if ($('#editCountryName').val()=="0"){
-            $('#ErreditCountryName').html("Please select Country Name");
+            $('#ErreditCountryName').html("Please Select Country Name");
              $("#editCountryName").addClass("highlight_error"); 
            error++;
     }  else {
@@ -340,21 +398,101 @@ function edit(){
           $("#editDistrictName").removeClass("highlight_error"); 
             $('#ErreditDistrictName').html(""); 
     }  
-     if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
+    if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=mcdnl",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+       } 
+  
+}
+
+function viewform(ID){
+     $('#confirmationtoview').modal("show");
+      $.post(URL+ "webservice.php?action=g&method=mcdnl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCountryNameID').html(data.CountryName=="" ? "&nbsp" : data.CountryName);
+                $('#viewStateNameID').html(data.StateName=="" ? "&nbsp" : data.StateName);
+                $('#viewDistrictName').html(data.DistrictName=="" ? "&nbsp" : data.DistrictName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  }) 
+}
+
+function listCountryNames(formID,selectboxID,selected) {
+    var param = $('#'+formID).serialize();
+    $.post(URL+ "webservice.php?action=lac&method=mccol",param,function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "<option value='0'>Select Country Name</option>";
+            $.each(obj.data, function (index, data) {
+                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.CountryName+'</option>';
+            });   
+                $('#'+selectboxID).html(html);
+        } else {
+             var html = "<option value='0'>Select Country Name</option>";
+              $('#'+selectboxID).html(html);
+           // $('#ErrCommon').html( errorcontent(obj.message));
+        }
+    })
+}
+
+
+
+function listStateNames(formID,selectboxID,selected) {
+    
+    var html = "<option value='0'>Select State Name</option>";
+             $('#'+selectboxID).html(html);
+    if (formID=="frm_create") {
+          if ($('#CountryNameID').val()=="0") {
+              var html = "<option value='0'>Select State Name</option>";
+             $('#'+selectboxID).html(html);
+          }
     }
+    if (formID=="frm_edit") {
+         if ($('#editCountryNameID').val()=="0") {
+              var html = "<option value='0'>Select State Name</option>";
+             $('#'+selectboxID).html(html);
+          }
+        
+    }
+      var param = $('#'+formID).serialize();
+    $.post(URL+ "webservice.php?action=labc&method=mcsnl",param,function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            if (obj.data.length>0) {
+            var html = "<option value='0'>Select State Name</option>";
+            $.each(obj.data, function (index, data) {
+                html += '<option value="'+ data.ID +'" '+((data.ID==selected) ? ' selected="selected" ' : '')+' ">'+data.StateName+'</option>';
+            });
+            $('#'+selectboxID).html(html);
+            }
+        } else {
+             var html = "<option value='0'>Select State Name</option>";
+             $('#'+selectboxID).html(html);
+           // $('#ErrCommon').html( errorcontent(obj.message));
+        }
+    })
 }
 
-function viewform(){
-     $('#confirmationtoview').modal("show"); 
-}
-
-
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
-
+   
 //Character Limitations
  
 
