@@ -11,16 +11,14 @@
                 <table id="listTable" class="table" style="width:100%">
                     <thead>
                         <tr>
-                            <th>Code</th>
+                            <th style="width:150px">Code</th>
                             <th>Institution Type</th>
-                            <th>Status</th>
-                            <th></th>
-                            <th></th>
+                            <th style="width:50px">Status</th>
+                            <th style="width:100px"></th>
                         </tr>
-                    </thead>
-                    <tbody>
-                        <tr>
-                            <td colspan='4'>
+                    </thead>                                     
+                    <tbody id="tbl_content"> <tr>
+                        <td colspan='4'>
                                 <?php echo loadingText("Loading Institution Types");?>
                             </td>
                         </tr>
@@ -31,23 +29,6 @@
     </div>
 </div>
 
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                <button class="btn-close" data-dismiss="modal"></button>
-            </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
-    </div>
-</div>
-
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
@@ -56,7 +37,9 @@
                 <button class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+            <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                 <div class="row">
+                    <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')"></input>
@@ -64,7 +47,7 @@
                     </div>
                     <div class="col-12">
                         <label class="form-label">Institution Type</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="InstitutionType" id="InstitutionType" placeholder="Institution Type" onchange="clearInput('InstitutionType')"></input>
+                         <input class="form-control form-control-sm" type="text" name="InstitutionType" id="InstitutionType" placeholder="Institution Type" onkeypress="clearInput('InstitutionType')"></input>
                         <span id="ErrInstitutionType" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
@@ -73,6 +56,7 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+            </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -90,22 +74,25 @@
                 <button class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+                <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                     <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')"></input>
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')"></input>
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">Institution Type</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="InstitutionType" id="editInstitutionType" placeholder="Institution Type" value="" onchange="clearInput('editInstitutionType')"></input>
+                         <input class="form-control form-control-sm" type="text" name="InstitutionType" id="editInstitutionType" placeholder="Institution Type" value="" onkeypress="clearInput('editInstitutionType')"></input>
                         <span id="ErreditInstitutionType" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['IsActive']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['IsActive']==0) ? " selected='selected' ": "''";?>>Deactive</option>
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
@@ -115,6 +102,7 @@
                     </div>
                     
                 </div>
+                </form>
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -135,23 +123,23 @@
                 <div class="row">
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Code</div>
-                        
+                        <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Institution Type</div>
-                       
+                         <div id="viewInstitutionType"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                       
+                        <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        
+                        <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        
+                        <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
@@ -169,13 +157,48 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=mcitl","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.InstitutionType + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mcitl\',\''+data.InstitutionType+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
+}
+
+setTimeout("list()",2000);
+
 function addform(){
         $('#confirmationtoadd').modal("show");
         $('#Code').val(""); 
@@ -210,13 +233,21 @@ function add(){
          $("#InstitutionType").removeClass("highlight_error");
             $('#ErrInstitutionType').html(""); 
     } 
-     if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=mcitl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   } 
 }
 
-function editform(){
+function editform(ID){
      $('#confirmationtoedit').modal("show"); 
      $('#ErreditCode').html(""); 
      $('#ErreditInstitutionType').html(""); 
@@ -224,9 +255,25 @@ function editform(){
      $("#editCode").removeClass("highlight_error");
      $("#editInstitutionType").removeClass("highlight_error");
      $("#editRemarks").removeClass("highlight_error");
+      $.post(URL+ "webservice.php?action=g&method=mcitl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editInstitutionType').val(data.InstitutionType);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+            });   
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });
 }
 
-function edit(){
+function edit(ID){
       var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -241,24 +288,45 @@ function edit(){
             $('#ErreditInstitutionType').html("Please enter Institution Type");
           $("#editInstitutionType").addClass("highlight_error");
             error++;
-    }  else {
+    }  else {                                                                                                         
          $("#editInstitutionType").removeClass("highlight_error");
             $('#ErreditInstitutionType').html(""); 
     }  
-     if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=mcitl",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+       } 
 }
 
-function viewform(){
+function viewform(ID){
      $('#confirmationtoview').modal("show"); 
+      $.post(URL+ "webservice.php?action=g&method=mcitl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewInstitutionType').html(data.InstitutionType=="" ? "&nbsp" : data.InstitutionType);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  })
 }
 
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
- 
  //Character Limitations
  
 
