@@ -2,7 +2,7 @@
     <div class="container">
         <div class="row">
             <div class="col-6"> 
-                <h3>Langugages</h3>
+                <h3>Languges</h3>
             </div>
             <div class="col-6" style="text-align: right;"> 
                 <button class="btn-save" onclick="addform()">New</button>
@@ -310,10 +310,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewLanguageName').html(data.LanguageName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewLanguageName').html(data.LanguageName=="" ? "&nbsp;" : data.LanguageName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
