@@ -312,10 +312,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewMaritalStatus').html(data.MaritalStatus);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewMaritalStatus').html(data.MaritalStatus=="" ? "&nbsp;" : data.MaritalStatus);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
