@@ -80,8 +80,8 @@
                 <div class="row">
                  <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
@@ -310,10 +310,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewNationalityName').html(data.NationalityName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewNationalityName').html(data.NationalityName=="" ? "&nbsp;" : data.NationalityName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
