@@ -8,31 +8,28 @@
                          <div class="col-6" style="text-align: right;"> 
                             <button class="btn-save" onclick="addform()">New</button>
                          </div>
-                        </div>                                                 
+                        </div>                                                                         
                         </div>
                    <div class="row">
                 <div class="col-xl-12 col-lg-12">
                     <div class="transactions-table table">
                         <div class="table">
-                            <table id="example" class="table" style="width:100%">
+                            <table id="listTable" class="table" style="width:100%">
                                 <thead>
                                     <tr>
-                                        <th>Code</th>
+                                        <th style="width:150px">Code</th>
                                         <th>State Name</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
+                                        <th>Country Name</th>
+                                        <th style="width:50px">Status</th>
+                                        <th style="width:100px"></th>
                                     </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
+                                </thead>                                     
+                                <tbody id="tbl_content"> <tr>
+                                    <td colspan='4'>
+                                            <?php echo loadingText("Loading State Names");?>
+                                        </td>
+                                    </tr>
+                                </tbody>
                             </table>
                         </div>
                     </div>
@@ -40,22 +37,6 @@
             </div>
             </div>
 </div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                <button type="button" class="btn-close" data--dismiss="modal"></button>
-            </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
-    </div>
-</div>
 
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
@@ -65,7 +46,9 @@
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
-                <div class="row">
+                 <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
+                 <div class="row">
+                     <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
@@ -73,11 +56,10 @@
                     </div>
                      <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="CountryName" onchange="clearInput('CountryName')">
+                         <select class="form-select form-select-sm" name="CountryNameID" id="CountryNameID" onchange="clearInput('CountryNameID')">
                             <option value="0">Select Country Name</option>
-                            <option value="1">Country Name</option>
                          </select>
-                        <span id="ErrCountryName" class="error_msg" style="color: red;"></span>
+                        <span id="ErrCountryNameID" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
@@ -90,6 +72,7 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -107,38 +90,42 @@
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
-                <div class="row">
+                 <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                 <input type="hidden" name="ID" id="editID">
+                    <div class="row">
+                    <span id="ErreditCommon"></span>
                     <div class="col-6">
-                        <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
+                        <label class="form-label">Code</label>
+                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="editCountryName" value="<?php echo $data[0]['Country'];?>" onchange="clearInput('editCountryName')">
+                         <select class="form-select form-select-sm" name="CountryNameID" id="editCountryNameID" value="" onchange="clearInput('editCountryNameID')">
                             <option value="0">Select Country Name</option>
                             <option value="1">Country Name</option>
                          </select>
-                        <span id="ErreditCountryName" class="error_msg" style="color: red;"></span>
+                        <span id="ErreditCountryNameID" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="StateName" id="editStateName" placeholder="State Name" value="<?php echo $data[0]['StateName'];?>" onkeypress="clearInput('editStateName')">
+                         <input class="form-control form-control-sm" type="text" name="StateName" id="editStateName" placeholder="State Name" value="" onkeypress="clearInput('editStateName')">
                         <span id="ErreditStateName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('Code')">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Code')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                </form>
             </div>
                  <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -159,32 +146,32 @@
                 <div class="row">
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
+                         <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Country Name</div>
-                        <?php echo $data[0]['CountryName'];?>
+                         <div id="viewCountryNameID"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">State Name</div>
-                        <?php echo $data[0]['StateName'];?>
+                         <div id="viewStateName"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                         <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['Status'];?>
+                         <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                         <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -197,30 +184,64 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
-      
+
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=mcsnl","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.StateName + '</td>' 
+                            + '<td>' + data.CountryName + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mcsnl\',\''+data.StateName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="5" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
+
 function addform(){
+              
+listCountryNames("0","CountryNameID");
     $('#confirmationtoadd').modal("show");
     $('#Code').val("");
-    $('#CountryName').val("0");  
+    $('#CountryNameID').val("0");  
     $('#StateName').val(""); 
     $('#Remarks').val("");
     $('#ErrCode').html(""); 
-    $('#ErrCountryName').html(""); 
+    $('#ErrCountryNameID').html(""); 
     $('#ErrStateName').html(""); 
     $('#ErrRemarks').html(""); 
     $("#Code").removeClass("highlight_error");  
-    $("#CountryName").removeClass("highlight_error");  
+    $("#CountryNameID").removeClass("highlight_error");  
     $("#StateName").removeClass("highlight_error");  
     $("#Remarks").removeClass("highlight_error");  
 }
@@ -243,35 +264,62 @@ function add(){
          $("#StateName").removeClass("highlight_error");  
             $('#ErrStateName').html(""); 
     } 
-    if ($('#CountryName').val()=="0"){
-            $('#ErrCountryName').html("Please select Country Name");
-         $("#CountryName").addClass("highlight_error");  
+    if ($('#CountryNameID').val()=="0"){
+            $('#ErrCountryNameID').html("Please select Country Name");
+         $("#CountryNameID").addClass("highlight_error");  
            error++;
     }  else {
-         $("#CountryName").removeClass("highlight_error");  
-          $('#ErrCountryName').html(""); 
+         $("#CountryNameID").removeClass("highlight_error");  
+          $('#ErrCountryNameID').html(""); 
     } 
-     if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
-   
-   
+      if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=mcsnl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   } 
 }
 
-function editform(){
+function editform(ID){
      $('#confirmationtoedit').modal("show");
       $("#editCode").removeClass("highlight_error");  
-      $("#editCountryName").removeClass("highlight_error");  
+      $("#editCountryNameID").removeClass("highlight_error");  
       $("#editStateName").removeClass("highlight_error");  
       $("#Remarks").removeClass("highlight_error"); 
       $('#ErreditCode').html(""); 
-      $('#ErreditCountryName').html(""); 
+      $('#ErreditCountryNameID').html(""); 
       $('#ErreditStateName').html(""); 
-      $('#ErreditRemarks').html(""); 
+      $('#ErreditRemarks').html("");
+      $.post(URL+ "webservice.php?action=g&method=mcsnl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            _CountryNameID="";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editStateName').val(data.StateName);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+                _CountryNameID=data.CountryNameID;
+            });
+            if (obj.data.length>0)    {
+                 listCountryNames(_CountryNameID,"editCountryNameID");
+            }
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  }); 
 }
 
-function edit(){
+function edit(ID){
     var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -289,62 +337,68 @@ function edit(){
         $("#editStateName").removeClass("highlight_error"); 
             $('#ErreditStateName').html(""); 
     }  
-    if ($('#editCountryName').val()=="0"){
-            $('#ErreditCountryName').html("Please select Country Name");
-           $("#editCountryName").addClass("highlight_error"); 
+    if ($('#editCountryNameID').val()=="0"){
+            $('#ErreditCountryNameID').html("Please select Country Name");
+           $("#editCountryNameID").addClass("highlight_error"); 
            error++;
     }  else {
-          $("#editCountryName").removeClass("highlight_error"); 
-            $('#ErreditCountryName').html(""); 
+          $("#editCountryNameID").removeClass("highlight_error"); 
+            $('#ErreditCountryNameID').html(""); 
     } 
-      if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=mcsnl",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+       } 
   
 }
 
-function viewform(){
+function viewform(ID){
      $('#confirmationtoview').modal("show"); 
+      $.post(URL+ "webservice.php?action=g&method=mcsnl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewCountryNameID').html(data.CountryName=="" ? "&nbsp" : data.CountryName);
+                $('#viewStateName').html(data.StateName=="" ? "&nbsp" : data.StateName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  })
 }
 
-function Code_Err() {
-     $('#ErrCode').html("");
-      document.getElementById("Code").style["boxShadow"] = "";
-      Code.style.border = "1px solid #4776e6";
- } 
- 
-function StateName_Err() {
-     $('#ErrStateName').html("");
-      document.getElementById("StateName").style["boxShadow"] = "";
-      StateName.style.border = "1px solid #4776e6";
- }
- function CountryName_Err() {
-     $('#ErrCountryName').html("");
-      document.getElementById("CountryName").style["boxShadow"] = "";
-      CountryName.style.border = "1px solid #4776e6";
- }
- 
- function editCode_Err() {
-     $('#ErreditCode').html("");
-      document.getElementById("editCode").style["boxShadow"] = "";
-      editCode.style.border = "1px solid #4776e6";
- }
-
- function editStateName_Err() {
-     $('#ErreditStateName').html("");
-      document.getElementById("editStateName").style["boxShadow"] = "";
-      editStateName.style.border = "1px solid #4776e6";
- }
- function editCountryName_Err() {
-     $('#ErreditCountryName').html("");
-      document.getElementById("editCountryName").style["boxShadow"] = "";
-      editCountryName.style.border = "1px solid #4776e6";
- } 
-
-function dashboard()  {
-  location.href='dashboard.php';                                                              
+function listCountryNames(selected,selectboxID) {
+    $.post(URL+ "webservice.php?action=lac&method=mccol","",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "<option value='0'> Select Country Name</option>";
+            $.each(obj.data, function (index, data) {
+                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.CountryName+'</option>';
+            });   
+                $('#'+selectboxID).html(html);
+        } else {
+            $('#ErrCommon').html( errorcontent(obj.message));
+        }
+    })
 }
+
+
+
  
 //Character Limitations
  
