@@ -152,28 +152,16 @@
     </div>
 </div>
 
-<div class="modal fade" id="success_modal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-body" style="text-align: center;">
-                <div id="sucess">
-                    <img id="Sucess" style="width: 150px;" src="sucess.gif" alt=""/>
-                </div>
-                <h3 id="success_modal_title"></h3>  
-                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
-            </div>
-        </div>
-    </div>
-</div>
+                                                                  
 
-<div class="modal fade" id="Failure" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
+<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
             <div class="modal-body" style="text-align: center;">
                 <div id="sucess">
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
-                <h3 class="title"><span id="ErrNewCommon" class="error_msg" style="color: red;"></span></h3> 
+                <h3 class="title">Success.</h3>  
                  <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
@@ -183,7 +171,7 @@
 <script>
 
 function list() {
-      $('#success_modal').modal("hide");
+      $('#Success').modal("hide");
     $.post(URL+ "webservice.php?action=l&method=mmal","",function(data){
       var obj = JSON.parse(data);
         if (obj.status=="success") {
@@ -244,7 +232,7 @@ function add() {
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoadd').modal("hide"); 
-             $('#success_modal').modal("show");    
+             $('#Success').modal("show");    
         }   else {
             $('#ErrCommon').html(print_inlineError(obj.message));
         }
@@ -320,7 +308,7 @@ function update(){
         var obj = JSON.parse(data); 
         if (obj.status=="success") {
              $('#confirmationtoedit').modal("hide");
-             $('#success_modal').modal("show");  
+             $('#Success').modal("show");  
         }   else {
             $('#ErreditCommon').html(print_inlineError(obj.message));
         }
@@ -336,10 +324,10 @@ function viewform(ID){
         var obj = JSON.parse(data);
         if (obj.status=="success") {
             $.each(obj.data, function (index, data) {
-                $('#viewCode').html(data.Code);
-                $('#viewAthleticName').html(data.AthleticName);
-                $('#viewRemarks').html(data.Remarks);
-                $('#viewCreatedOn').html(data.CreatedOn);
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewAthleticName').html(data.AthleticName=="" ? "&nbsp;" : data.AthleticName);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
                if(data.Status=="1"){
                 $('#viewStatus').html("Active");    
                }
