@@ -1,16 +1,5 @@
 <?php
-date_default_timezone_set('Asia/Calcutta'); 
-define("SERVER_PATH",__DIR__);
-define("log_path",SERVER_PATH."/logs/");
-define("sql_log",SERVER_PATH."/logs/");
-
-define("DBSERVER","localhost");                        
-define("DBUSER","j2jsoftwaresin_ims_user");       
-define("DBPASSWORD","Welcome@2024");
-define("DBNAME","j2jsoftwaresin_ims");
-
-include_once(SERVER_PATH."/controllers/class.DatabaseController.php");
-$mysql = new MySqldatabase(DBSERVER,DBUSER,DBPASSWORD,DBNAME);
+include_once("appconfig.php");
 
 
 class Tabels {                               
@@ -58,6 +47,13 @@ class Tabels {
 
     const StateNames= "_tbl_masters_common_statenames";
     const DistrictNames= "_tbl_masters_common_districtnames";
+    const SchemeNames= "_tbl_masters_appcommon_schemeNames";
+    const InstitutionTypes= "_tbl_masters_common_institutiontypes";
+    const SubjectNames= "_tbl_masters_academy_subjectnames";
+    
+    const CourseNames= "_tbl_masters_academy_coursenames";
+    const Gender= "_tbl_masters_common_gender";
+    const Batches= "_tbl_masters_academy_batches";
 }
 
 function hideMobilNumber($number) {
@@ -71,6 +67,12 @@ function isLogged() {
     return false;
 }
 
+ 
+$metohd['login']=array("classfile"=>"webservices/class.Login.php",
+                      "classname"=>"Login",
+                      "dol"=>"doLogin");
+                       
+                      
 $metohd['mmal']=array("classfile"=>"webservices/class.AthleticNames.php",
                       "classname"=>"AthleticNames",
                       "a"=>"addNew",
@@ -102,7 +104,7 @@ $metohd['macbel']=array("classfile"=>"webservices/class.BoardOfEducations.php",
                       "u"=>"doUpdate",
                       "l"=>"listAll",
                       "g"=>"getData",
-                      "e"=>"remove");
+                      "r"=>"remove");
 $metohd['macql']=array("classfile"=>"webservices/class.QualificationNames.php",
                       "classname"=>"QualificationNames",
                       "a"=>"addNew",
@@ -242,6 +244,7 @@ $metohd['mactl']=array("classfile"=>"webservices/class.CourseTypes.php",
                       "a"=>"addNew",
                       "u"=>"doUpdate",
                       "l"=>"listAll",
+                      "lac"=>"listActive", /*list all active*/
                       "g"=>"getData",
                       "r"=>"remove");
                             
@@ -250,6 +253,7 @@ $metohd['madl']=array("classfile"=>"webservices/class.Departments.php",
                       "a"=>"addNew",
                       "u"=>"doUpdate",
                       "l"=>"listAll",
+                      "lac"=>"listAllActive",
                       "g"=>"getData",
                       "r"=>"remove");
 
@@ -327,7 +331,7 @@ $metohd['masnl']=array("classfile"=>"webservices/class.SchoolNames.php",
                       "g"=>"getData",
                       "r"=>"remove");
 
-$metohd['macnl']=array("classfile"=>"webservices/class.CollegeNames.php",
+$metohd['macoll']=array("classfile"=>"webservices/class.CollegeNames.php",  
                       "classname"=>"CollegeNames",
                       "a"=>"addNew",
                       "u"=>"doUpdate",
@@ -349,6 +353,27 @@ $metohd['mccunl']=array("classfile"=>"webservices/class.CurrencyNames.php",
                       "l"=>"listAll",
                       "g"=>"getData",
                       "r"=>"remove");
+$metohd['macsl']=array("classfile"=>"webservices/class.SchemeNames.php",
+                      "classname"=>"SchemeNames",      
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");
+$metohd['mcitl']=array("classfile"=>"webservices/class.InstitutionTypes.php",
+                      "classname"=>"InstitutionTypes",      
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");
+$metohd['masul']=array("classfile"=>"webservices/class.SubjectNames.php",
+                      "classname"=>"SubjectNames",      
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");                      
                       
 $metohd['mcsnl']=array("classfile"=>"webservices/class.StateNames.php",
                       "classname"=>"StateNames",
@@ -367,6 +392,28 @@ $metohd['mcdnl']=array("classfile"=>"webservices/class.DistrictNames.php",
                       "g"=>"getData",
                       "r"=>"remove");
                       
+$metohd['macoul']=array("classfile"=>"webservices/class.CourseNames.php",
+                      "classname"=>"CourseNames",
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");
+$metohd['mcgndrl']=array("classfile"=>"webservices/class.Gender.php",
+                      "classname"=>"Gender",
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");
+$metohd['mabl']=array("classfile"=>"webservices/class.Batches.php",
+                      "classname"=>"Batches",
+                      "a"=>"addNew",
+                      "u"=>"doUpdate",
+                      "l"=>"listAll",
+                      "g"=>"getData",
+                      "r"=>"remove");
+                      
                       
                       
                        
@@ -397,7 +444,7 @@ if (isset($metohd[$_GET['method']])) {
     $class  = $metohd[$_GET['method']]['classname'];
     $action = $metohd[$_GET['method']][$_GET['action']];
     $ws = new $class();
-    echo $ws->$action();
+    echo $ws->$action(); 
 } else {
    echo "error";
 }
